#[non_exhaustive]pub enum StateEventFormat {
Content,
Event,
}Available on crate features
client or server only.Expand description
The format to use for the returned data.
This type can hold an arbitrary string. To build this with a custom value, convert it from a
string with ::from() / .into(). To check for values that are not available as a
documented variant here, use its string representation, obtained through
.as_str().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Content
Will return only the content of the state event.
This is the default value if the format is unspecified in the request.
Event
Will return the entire event in the usual format suitable for clients, including fields like event ID, sender and timestamp.
Implementations